from setuptools import setup, find_packages


setup(
    name='flashquiz',
    version="0.0b1",
    description='[TEST VERSION] Quiz yourself on your flashcards',
    author='mike-fmh',
    author_email='mikemh@uri.edu',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'pygame'
    ]
)
